%define evo_version 2.11.0
%define eds_version 1.11.0
%define intltool_version 0.35.0
%define libsoup_version 2.2.6.1

%define eds_major 1.2
%define evo_major 2.12

# Make sure the evolution package is upgraded first, or else this variable
# will come up empty and lead to the following libtool error.
#
# 	libtool: link: only absolute run-paths are allowed
#
# The error is caused by the -R ${plibdir} substitution below; -R requires
# an argument and libtool does not complain until late in the game.  Seems
# like it could be smarter about this.
%define plibdir %(pkg-config evolution-shell --variable=privlibdir 2>/dev/null)

# Use stricter build settings than required by upstream.
%define strict_build_settings 1

### Abstract ###

Name: evolution-connector
Version: 2.12.3
Release: 4%{?dist}.1
License: GPL
Group: Applications/Productivity
Summary: Evolution plugin to interact with MS Exchange Server
URL: http://www.gnome.org/projects/evolution/
Source: evolution-exchange-%{version}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{version}-root

### Patches ###

Patch11: evolution-exchange-2.10.1-fix-64bit-acinclude.m4.patch

# Remove gnome-common macros from configure.in.
# We do not ship gnome-common (or at least we're not supposed to).
Patch12: evolution-exchange-2.7.2-no_gnome_common.patch

# GNOME bug #443022
Patch13: evolution-exchange-2.11.2-fix-library-order.patch

# RH bug #220359 (lame hack)
Patch14: evolution-exchange-2.12.3-ldap-op-finished.patch

# RH bug #446173 / GNOME bug #444503
Patch15: evolution-exchange-2.12.3-fix-filtering.patch

### Dependencies ###

Requires: openldap

### Build Dependencies ###

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: db4-devel
BuildRequires: evolution-data-server-devel >= %{eds_version}
BuildRequires: evolution-devel >= %{evo_version}
BuildRequires: gettext
BuildRequires: gnutls-devel
BuildRequires: gtk-doc
BuildRequires: intltool >= %{intltool_version}
BuildRequires: libsoup-devel >= %{libsoup_version}
BuildRequires: libtool >= 1.5
BuildRequires: openldap-evolution-devel
BuildRequires: openssl-devel

%description
This package enables added functionality to Evolution when used with a 
Microsoft Exchange Server.

%prep
%setup -q -n evolution-exchange-%{version}

%patch11 -p1 -b .fix-64bit-acinclude.m4
%patch12 -p1 -b .no_gnome_common
%patch13 -p1 -b .fix-library-order
%patch14 -p1 -b .ldap-op-finished
%patch15 -p1 -b .fix-filtering

%build
export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED"
# Set LIBS so that configure will be able to link with static LDAP libraries,
# which depend on Cyrus SASL and OpenSSL.
if pkg-config openssl ; then
	LIBS="-lsasl2 `pkg-config --libs openssl`"
else
	LIBS="-lsasl2 -lssl -lcrypto"
fi
export LIBS

# Add stricter build settings here as the source code gets cleaned up.
# We want to make sure things like compiler warnings and avoiding deprecated
# functions in the GNOME/GTK+ libraries stay fixed.
#
# Please file a bug report at bugzilla.gnome.org if these settings break
# compilation, and encourage the upstream developers to use them.

%if %{strict_build_settings}
CFLAGS="$CFLAGS \
	-DG_DISABLE_DEPRECATED=1 \
	-DPANGO_DISABLE_DEPRECATED=1 \
	-DGDK_PIXBUF_DISABLE_DEPRECATED=1 \
	-DGDK_DISABLE_DEPRECATED=1 \
	-DGTK_DISABLE_DEPRECATED=1 \
	-DEDS_DISABLE_DEPRECATED=1 \
	-Wdeclaration-after-statement \
	-Werror-implicit-function-declaration \
	-Werror"
%endif

# Regenerate configure to pick up acinclude.m4 changes.
autoreconf --force

%configure \
  --enable-gtk-doc \
  --with-openldap=%{_libdir}/evolution-openldap \
  --with-static-ldap

make %{?_smp_mflags} LDFLAGS="-R %{plibdir}"

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
rm -f $RPM_BUILD_ROOT/%{_libdir}/evolution-data-server-%{eds_major}/camel-providers/*.a
%find_lang evolution-exchange-%{evo_major}

%post
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule %{_sysconfdir}/gconf/schemas/apps_exchange_addressbook-%{evo_major}.schemas > /dev/null

%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%files -f evolution-exchange-%{evo_major}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING INSTALL NEWS docs/active-directory
%doc docs/autoconfig docs/debug docs/forms
%doc docs/http
%{_bindir}/exchange-connector-setup-%{evo_major}
%{_libdir}/bonobo/servers/GNOME_Evolution_Exchange_Storage_%{evo_major}.server
%{_libdir}/evolution-data-server-%{eds_major}/camel-providers/libcamelexchange.so
%{_libdir}/evolution-data-server-%{eds_major}/camel-providers/libcamelexchange.la
%{_libdir}/evolution-data-server-%{eds_major}/camel-providers/libcamelexchange.urls
%{_libexecdir}/evolution/%{evo_major}/evolution-exchange-storage 
%{_datadir}/gtk-doc/html/ximian-connector
%{_datadir}/evolution-exchange/%{evo_major}/glade/*.glade
%{_datadir}/evolution-exchange/%{evo_major}/images/*.png
%{_datadir}/evolution-exchange/%{evo_major}/ui/ximian-connector.xml
%{_sysconfdir}/gconf/schemas/apps_exchange_addressbook-%{evo_major}.schemas

%changelog
* Mon May 13 2008 Matthew Barnes <mbarnes@redhat.com> - 2.12.3-4.el5_2.1
- Add patch for RH bug #446173 (broken mail filters).

* Mon Feb 11 2008 Matthew Barnes <mbarnes@redhat.com> - 2.12.3-4.el5
- Rebuild against reverted Camel sonames... again.

* Thu Jan 31 2008 Matthew Barnes <mbarnes@redhat.com> - 2.12.3-3.el5
- Rebuild against reverted Camel sonames.

* Tue Jan 15 2008 Matthew Barnes <mbarnes@redhat.com> - 2.12.3-2.el5
- Add patch for RH bug #220359 (crash in GAL lookup).

* Mon Jan 07 2008 Matthew Barnes <mbarnes@redhat.com> - 2.12.3-1.el5
- Update to 2.12.3

* Mon Nov 26 2007 Matthew Barnes <mbarnes@redhat.com> - 2.12.2-1.el5
- Update to 2.12.2

* Sun Nov 04 2007 Matthew Barnes <mbarnes@redhat.com> - 2.12.1-1.el5
- Rebase to 2.12.1

* Sun Oct 01 2006 Jesse Keating <jkeating@redhat.com> - 2.8.0-3.fc6
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Mon Sep 25 2006 Matthew Barnes <mbarnes@redhat.com> - 2.8.0-2.fc6
- Add patch for Gnome.org bug #357660.

* Mon Sep  4 2006 Matthew Barnes <mbarnes@redhat.com> - 2.8.0-1.fc6
- Update to 2.8.0
- Remove patch for Gnome.org bug #349949 (fixed upstream).

* Mon Aug 21 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.92-1
- Update to 2.7.92

* Mon Aug  7 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.91-2
- Rebuild against correct evolution-data-server.

* Mon Aug  7 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.91-1
- Update to 2.7.91

* Sat Aug  5 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.90-3
- Fix eds_major (bumped it when I shouldn't have).

* Sat Aug  5 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.90-1
- Update to 2.7.90

* Wed Jul 12 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.4-1
- Update to 2.7.4

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.7.3-2.1
- rebuild

* Wed Jun 14 2006 Matthias Clasen <mclasen@redhat.com> - 2.7.3-2
- Rebuild 

* Wed Jun 14 2006 Matthias Clasen <mclasen@redhat.com> - 2.7.3-1
- Update to 2.7.3

* Wed May 24 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.2-2
- Add BuildRequires for gtk-doc (closes #192251).
- Require specific versions of GNU Autotools packages for building.
- Various spec file cleanups.

* Wed May 17 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.2-1
- Update to 2.7.2
- Update spec file to run the autotools itself after patching.
- Remove evolution-exchange-2.7.1-fix_version.patch; fixed upstream.
- Remove unused or obsolete patches:
  evolution-connector-2.0.2-domain-fix.patch
  evolution-connector-2.7.2-generated-autotool.patch
  ximian-connector-2.1.4-fix-convenience-libraries.patch
  ximian-connector-2.2.2-install-debug-utilities.patch
  ximian-connector-2.2.2-noinst-ltlibraries.patch
- Add evolution-exchange-2.7.2-no_gnome_common.patch; removes
  GNOME_COMPILE_WARNINGS from configure.in.

* Sun May 14 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.1-2
- Forgot to add evolution-exchange-2.7.1-fix_version.patch to CVS.

* Fri May 12 2006 Matthew Barnes <mbarnes@redhat.com> - 2.7.1-1
- Update to 2.7.1
- Add some comments about the `plibdir' variable.
- Add --enable-gtk-doc to the `configure' invocation.
- Add temporary patch evolution-exchange-2.7.1-fix_version.patch.

* Mon Apr 10 2006 Matthias Clasen <mclasen@redhat.com> - 2.6.1-2
- Update to 2.6.1

* Mon Mar 13 2006 Ray Strode <rstrode@redhat.com> - 2.6.0-1
- 2.6.0

* Tue Feb 28 2006 Ray Strode <rstrode@redhat.com> - 2.5.92-1
- 2.5.92

* Wed Feb 15 2006 David Malcolm <dmalcolm@redhat.com> - 2.5.91-1
- 2.5.91
- fix missing declarations (patch 301)

* Mon Feb 13 2006 Jesse Keating <jkeating@redhat.com> - 2.5.9.0-2.2.1
- rebump for build order issues during double-long bump

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.5.9.0-2.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.5.9.0-2.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Tue Jan 31 2006 Ray Strode <rstrode@redhat.com> - 2.5.9.0-2
- add builddeps (bug 137879)

* Mon Jan 30 2006 David Malcolm <dmalcolm@redhat.com> - 2.5.9.0-1
- 2.5.9.0
- regenerate patch 200
- enable parallel make

* Wed Jan 25 2006 David Malcolm <dmalcolm@redhat.com> - 2.5.5.1-1
- 2.5.5.1
- regenerate patch 200

* Wed Jan  4 2006 David Malcolm <dmalcolm@redhat.com> - 2.5.4-1
- 2.5.4

* Mon Dec 19 2005 David Malcolm <dmalcolm@redhat.com> - 2.5.3-1
- 2.5.3
- regenerate patch 200
- add patch to use correct marshalling code (patch 300)
- dropped glob of etspec files

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Dec  7 2005 David Malcolm <dmalcolm@redhat.com> - 2.5.2-1
- 2.5.2
- bump evo_major from 2.4 to 2.6
- bump evolution requirement from 2.4.1 to 2.5.2 to ensure we get an appropriate
  underlying version of evolution
- regenerate patch 200

* Fri Dec  2 2005 David Malcolm <dmalcolm@redhat.com> - 2.4.2-1
- 2.4.2
- regenerate patch 200; forcing regeneration of intltool scripts to 
  keep them in sync with our aclocal/intltool.m4
 
* Tue Nov 29 2005 David Malcolm <dmalcolm@redhat.com> - 2.4.1-3
- add -DLDAP_DEPRECATED to CFLAGS (#172999)

* Wed Nov  9 2005 Tomas Mraz <tmraz@redhat.com> - 2.4.1-2
- rebuilt with new openssl

* Tue Oct 18 2005 David Malcolm <dmalcolm@redhat.com> - 2.4.1-1
- 2.4.1
- bump evolution requirement to 2.4.1 and libsoup requirement to 2.2.6.1
- fix URL to point to 2.4, not 2.3

* Thu Sep 15 2005 Jeremy Katz <katzj@redhat.com> - 2.4.0-2
- rebuild for new e-d-s

* Wed Sep  7 2005 David Malcolm <dmalcolm@redhat.com> - 2.4.0-1
- 2.4.0
- Regenerated patch 200

* Wed Aug 24 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.8-1
- 2.3.8
- Regenerated patch 200
- Add -Werror-implicit-function-declaration to CFLAGS; make it use RPM_OPT_FLAGS

* Mon Aug 15 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.7-2
- rebuild

* Tue Aug  9 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.7-1
- 2.3.7
- Bump evolution requirement from 2.3.5.1 to 2.3.7
- Bump libsoup requirement from 2.2.2 to 2.2.5
- Remove ximian-connector-2.0.4-fix-sync-callback.patch; a slightly modified 
  version of this is now in the upstream tarball (#139393)

* Mon Aug  8 2005 Tomas Mraz <tmraz@redhat.com> - 2.3.6-3
- rebuild with new gnutls

* Mon Aug  1 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.6-2
- bump evo_major from 2.2 to 2.4
- Removed the various test programs (they no longer exist in the upstream 
  tarball)
- Renamed more instances of "ximian-connector" to "evolution-exchange" as
  appropriate.

* Thu Jul 28 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.6-1
- 2.3.6

* Tue Jul 26 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.5-2
- increase evolution requirement to 2.3.5.1

* Mon Jul 25 2005 David Malcolm <dmalcolm@redhat.com> - 2.3.5-1
- 2.3.5
- Changed various references to source tarball name from ximian-connector to
  evolution-exchange and updated the URL
- Remove Patch101 and Patch102 from autotool source patches and regenerate 
  resulting post-autotool patch

* Wed May 18 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.2-5
- add Aaron Gaudio's patch to fix PDA syncronization (#139393)

* Tue May 17 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.2-4
- Install the debug utilities from the "lib" subdirectory; renumber patches 
  accordingly; regenerate the generated patch

* Wed May  4 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.2-3
- updated noinst patch: libexchange is now a convenience library again; use -R
syntax to express path to Evolution's private libraries rather than -Wl since
libtool cannot properly intrepret the latter; regenerated resulting patch.

* Mon May  2 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.2-2
- disabling noinst patch as not yet applied

* Mon Apr 11 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.2-1
- 2.2.2

* Thu Mar 17 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.1-1
- 2.2.1
- Regenerated autotool patch

* Wed Mar  9 2005 David Malcolm <dmalcolm@redhat.com> - 2.2.0-1
- 2.2.0
- Updated evolution dependency to 2.2.0

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.6-3
- reapply the 64bit multilib LDAP patch, and regenerate the autotool patch accordingly

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.6-2
- actually remove the convenience library patches this time

* Wed Feb  9 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.6-1
- Update from unstable upstream 2.1.5 to 2.1.6
- Require evolution 2.1.6
- Removed patches for convenience libraries as these are now upstream

* Wed Feb  9 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.5-1
- Update from unstable upstream 2.1.4 to 2.1.5
- Require evolution 2.1.5

* Mon Feb  7 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.4-3
- Patch to fix non-portable usage of convenience libraries; reorganised the hand-edited vs generated patches (generated patch is 990K in size)
- Add "-Wl" to make arguments to escape usage of -rpath so it is seen by linker, but not by libtool,
enabling libexchange.la to install below /usr/lib/evolution-data-server-1.2/camel-providers, rather
than /usr/lib/evolution/2.2

* Mon Jan 31 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.4-2
- Split out the 64-bit acinclude.m4 patch into two patches, one containing the "actual" patch; the other containing all of the regenerated autotool results.
- Actually apply the 64-bit acinclude.m4 fix this time.

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 2.1.4-1
- Update from stable upstream 2.0.3 to unstable upstream 2.1.4
- Update evo_major from 2.0 to 2.2
- Added eds_major definition
- Require evolution 2.1.4
- Require libsoup 2.2.2
- Re-enable s390 architectures
- Cope with camel-providers now being stored below evolution-data-server, rather than evolution.
- Remove .a files from camel-providers subdir
- Removed various docs no longer present

* Wed Dec 15 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.3-1
- Update from upstream 2.0.2 to 2.0.3
- The fix for bugs #139134 and #141419 is now in the upstream tarball; removing the patch

* Tue Nov 30 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.2-2
- Added domain-fix.patch to fix bugs #139134 and #141419

* Tue Oct 12 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.2-1
- Update from 2.0.1 to 2.0.2
- exclude s390/s390x architecture for now due to Mozilla build problems
- refresh the autogenerated parts of the 64bit fix patch to patch over the latest version of autogenerated files from upstream

* Fri Oct  1 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.1-5
- added explicit gnutls requirement

* Fri Oct  1 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.1-4
- set libsoup requirement to be 2.2.0-2, to ensure gnutls support has been added

* Fri Oct  1 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.1-3
- added requirement on libsoup

* Fri Oct  1 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.1-2
- rebuild

* Thu Sep 30 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.1-1
- update from 2.0.0 to 2.0.1
- update required version of evolution from 1.5.94.1 to 2.0.1
- refresh the autogenerated parts of the 64bit fix patch to patch over the latest version of autogenerated files from upstream

* Mon Sep 20 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Tue Sep 14 2004 David Malcolm <dmalcolm@redhat.com> - 2.0.0-1
- update from 1.5.94.1 to 2.0.0
- update source FTP location from 1.5 to 2.0

* Wed Sep  1 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.94.1-1
- update tarball and evolution-version from 1.5.93 to 1.5.94.1
- convert various occurrences of "1.5" in paths to "2.0" to reflect reorganisations of evolution and the connector
- refresh the autogenerated parts of the 64bit fix patch to patch over the latest version of autogenerated files from upstream

* Wed Aug 25 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.93-1
- updated from 1.5.92 to 1.5.93
- removed patch to compile against Evolution 1.5.93 (no longer needed; also was causing bug #130840)
- removed patch for LDAP detection
- added a patch to acinclude.m4 and configure.in to detect and use correct library paths (together with patching the files generated by autotools)

* Mon Aug 23 2004 Nalin Dahyabhai <nalin@redhat.com> - 1.5.92-3
- change macro names to not use "-"
- fix configure on multilib systems

* Fri Aug 20 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.92-2
- exclude ppc64 architecture due to Mozilla build problems

* Thu Aug 19 2004 Nalin Dahyabhai <nalin@redhat.com> 1.5.92-1
- Require a version of openldap-devel which provides evolution-specific libs.
- Use the evolution-specific static libraries from openldap-devel, taking into
  account the value of gcc's multidir setting.
- Set $LIBS before running configure so that libldap's dependencies get pulled
  in and we don't accidentally link against the system-wide copy, which would
  make all of this hoop jumping pointless.
- Tag translation files as language-specific using %%{find_lang}.
- Update to 1.5.92.
- Patch to compile against Evolution 1.5.93.

* Mon Jul 26 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.91-1
- Updated to version 1.5.91; updated evolution version to 1.5.91

* Tue Jul  6 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.90-1
- Updated to version 1.5.90; updated evolution version to 1.5.90

* Mon Jun 21 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.9-2
- actually uploaded the source tarball this time

* Mon Jun 21 2004 David Malcolm <dmalcolm@redhat.com> - 1.5.9-1
- 1.5.9 - first version for the 1.5.* series of Evolution: use revised LDAP detection, fix a build problem in migr-test, use -rpath with evolution 1.5's privlibdir

* Thu May 13 2004 David Malcolm <dmalcolm@redhat.com> - 1.4.7-1
- downgrade to version 1.4.7 for now; add various open-ldap requirements and configuration options

* Thu May 13 2004 David Malcolm <dmalcolm@redhat.com> - 1.4.7.1-1
- updated version to 1.4.7.1

* Wed May 12 2004 David Malcolm <dmalcolm@redhat.com> - 1.4.7-1
- added ldconfig foo; build requires evolution-devel

* Tue May 11 2004 Tom "spot" Callaway <tcallawa@redhat.com>
- initial package
